@@ -1,6 +1,6 @@
 from pathlib import Path
 
-from ..io import read_sql_file
+from ..file_ops import read_sql_file
 from ..result import DataCheckResult, ResultType
 from .base_check import BaseCheck
 
