@@ -6,10 +6,11 @@ from functools import partial
 from pathlib import Path
 from typing import TYPE_CHECKING, Any, Callable, Dict, List, Optional, Union, cast
 
+from data_check.config import DataCheckConfig
 from data_check.sql.load_mode import LoadMode
 from data_check.utils.deprecation import deprecated_method
 
-from ...io import read_yaml
+from ...file_ops import read_yaml
 from ...result import DataCheckResult
 from ..base_check import BaseCheck
 from .cmd_step import CmdStep
@@ -66,6 +67,10 @@ class PipelineCheck(BaseCheck):
             convert_to_path_list=["configs"],
             convert_to_path=["output"],
         )
+        ping_step = partial(self.data_check.sql.test_connection, wait=True)
+        self.register_pipeline_step("ping", ping_step)
+        append_step = partial(self.load_table_or_tables, mode=LoadMode.APPEND)
+        self.register_pipeline_step("append", append_step)
 
     def load_table_or_tables(
         self,
