@@ -2,14 +2,16 @@ from pathlib import Path
 from typing import Optional, Union
 
 import click
+import colorama
 from click_default_group import DefaultGroup  # type: ignore
-from colorama import init
 
 from data_check.config import DataCheckConfig
 
+from .append import append
 from .common import common_options, init_common
 from .fake import fake
 from .generate import gen
+from .init import init
 from .load import load
 from .ping import ping
 from .run import run
@@ -29,7 +31,7 @@ def cli(
     quiet: bool = False,
     log: Optional[Union[str, Path]] = None,
 ):
-    init()  # init colorama
+    colorama.init()
     init_common(
         ctx=ctx,
         connection=connection,
@@ -47,4 +49,6 @@ cli.add_command(sql)
 cli.add_command(gen)
 cli.add_command(ping)
 cli.add_command(load)
+cli.add_command(append)
 cli.add_command(fake)
+cli.add_command(init)
