@@ -6,7 +6,7 @@ from typing import TYPE_CHECKING, Any, Dict, Optional, Tuple
 if TYPE_CHECKING:
     from data_check.sql.load_mode import LoadMode
 
-from .io import read_yaml
+from .file_ops import read_yaml
 
 TEMPLATE_FILE = "template.yml"
 CHECKS_PATH = "checks"
@@ -20,6 +20,9 @@ class DataCheckConfig:
 
     default_print_format = "csv"
 
+    wait_timeout = 5
+    wait_retry = 1
+
     def __init__(self, config_path: Optional[Path] = None) -> None:
         self.config: Dict[str, Any] = {}
         self.connection: Optional[str] = None
