@@ -1,6 +1,6 @@
 from functools import partial
 from pathlib import Path
-from typing import Any, Dict, List, Optional, Union
+from typing import Any, Dict, List, Optional, Set, Union
 
 from data_check.checks.base_check import BaseCheck
 
@@ -14,7 +14,7 @@ from .checks import (
     TableCheck,
 )
 from .config import DataCheckConfig
-from .io import expand_files, parse_template, read_sql_file, read_yaml
+from .file_ops import expand_files, parse_template, read_sql_file, read_yaml
 from .output import DataCheckOutput
 from .result import DataCheckResult
 from .runner import DataCheckRunner
@@ -64,6 +64,11 @@ class DataCheck:
             del check
         return result
 
+    def _get_check_or_generator(self, check_path, check) -> BaseCheck:
+        if self.config.generate_mode:
+            return DataCheckGenerator(self, check_path, check)
+        return check
+
     def get_check(self, check_path: Path) -> Optional[BaseCheck]:
         if PathNotExists.is_check_path(check_path):
             return PathNotExists(self, check_path)
@@ -74,25 +79,25 @@ class DataCheck:
         elif ExcelCheck.is_check_path(check_path):
             return ExcelCheck(self, check_path)
         elif CSVCheck.is_check_path(check_path):
-            if self.config.generate_mode:
-                return DataCheckGenerator(self, check_path)
-            else:
-                return CSVCheck(self, check_path)
+            csv_check = CSVCheck(self, check_path)
+            return self._get_check_or_generator(check_path, csv_check)
         elif TableCheck.is_check_path(check_path):
-            return TableCheck(self, check_path)
-        else:
-            return None
+            table_check = TableCheck(self, check_path)
+            return self._get_check_or_generator(check_path, table_check)
+        return None
 
     def collect_checks(
         self, files: List[Path], base_path: Path = Path(".")
     ) -> List[BaseCheck]:
         base_path = base_path.absolute()
         checks: List[BaseCheck] = []
+        check_paths: Set[Path] = set()
         for f in sorted(files):
             abs_file = f if f.is_absolute() else base_path / f
             check = self.get_check(abs_file)
-            if check is not None:
+            if check is not None and check.check_path not in check_paths:
                 checks.append(check)
+                check_paths.add(check.check_path)
             elif abs_file.is_dir():
                 dir_files = [d for d in abs_file.iterdir()]
                 checks.extend(self.collect_checks(dir_files, base_path=base_path))
