@@ -1,6 +1,7 @@
 from pathlib import Path
 
 from data_check.sql import DataCheckSql
+
 from .fake_config import FakeConfig
 
 
@@ -10,7 +11,7 @@ def fake_from_config(
     output: Path = Path(),
     force=False,
     base_path: Path = Path("."),
-):
+) -> bool:
     print("fake from", config)
     fake_config = FakeConfig(config)
     fake_config.parse()
