@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from dataclasses import dataclass
+from dataclasses import dataclass, field
 from pathlib import Path
 from typing import TYPE_CHECKING, Any, Dict
 
@@ -9,7 +9,7 @@ import pandas as pd
 if TYPE_CHECKING:
     from .fake_config import FakeConfig
 
-from data_check.io import read_csv, write_csv
+from data_check.file_ops import read_csv, write_csv
 
 from .iterators import dec, inc, random
 
@@ -18,7 +18,7 @@ from .iterators import dec, inc, random
 class FakeIterator:
     fake_config: FakeConfig
     count: int = 1
-    data: pd.DataFrame = pd.DataFrame()
+    data: pd.DataFrame = field(default_factory=pd.DataFrame)
 
     def load_config(self, config: Dict[str, Any]):
         self.count = config.get("count", 1)
