@@ -1,7 +1,9 @@
 from __future__ import annotations
-from typing import TYPE_CHECKING, Union
+
 import datetime
 import numbers
+from typing import TYPE_CHECKING, Any, Callable, Optional, Union
+
 import pandas as pd
 
 if TYPE_CHECKING:
@@ -17,7 +19,7 @@ def number_dec(x: Union[int, float]):
 
 
 def dec(column: ColumnConfig, data: pd.DataFrame):
-    apply_func = None
+    apply_func: Optional[Callable[..., Any]] = None
     if column.python_type in (datetime.date, datetime.datetime):
         apply_func = date_dec
     elif issubclass(column.python_type, numbers.Number):
